# orcidfind
Simple python script using the [Orcid Python Library](https://github.com/ORCID/python-orcid).  

This script adds command line interactivity that allows a user to search [Orcid](http://www.orcid.org) using the 
public API.  There are two search categories: basic search and advanced search.  The basic search allows a user to 
search Orcid for an Orcid user when the Orcid ID is not known.  The advanced search allows for more detailed
information to be accessed once the Orcid ID is known.  

The Orcid [public API](http://members.orcid.org/api) is used with this program.  There is no support for the member API.

## Download

## Usage

